"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userFlowReportToMdTable = void 0;
const prettier_1 = require("../../../core/utils/prettier");
const generate_reports_1 = require("../../collect/processes/generate-reports");
/**
 *
 * | Step Name       | Gather Mode |Performance | Accessibility | BestPractices | Seo  | PWA |
 * | --------------- | ----------- | ------------- | ------------- | ---- | --- |
 * |  Nav1           |  99         | 50            | 100           | 98   |  -  |
 * |  Snap   1       |  3/3        | 22/5          | 5/2           | 7/10 |  -  |
 * |  TimeSpan 1     |  10/11      | -             | 4/7           | 7/10 |  -  |
 */
function userFlowReportToMdTable(flowResult) {
    const reducedResult = (0, generate_reports_1.createReducedReport)(flowResult);
    const reportCategories = Object.keys(reducedResult.steps[0].results);
    const reportFormats = reportCategories.map(_ => 'c');
    // name is center, gather mode is center, all other columns are centered
    const TABLE_OPTIONS = { align: ['l', 'c'].concat(reportFormats) };
    const TABLE_HEAD = ['Step Name', 'Gather Mode']
        .concat(reportCategories
        .map(c => c.split('-').map(cN => cN[0].toUpperCase() + cN.slice(1)).join(' ')));
    const tableArr = [TABLE_HEAD].concat(reducedResult.steps.map((step) => (extractTableRow(step, reportCategories))));
    return markdownTable(tableArr, TABLE_OPTIONS).replace(' ', '') + `\n`;
}
exports.userFlowReportToMdTable = userFlowReportToMdTable;
function markdownTable(data, { align }) {
    const _data = data.map((arr) => arr.join('|'));
    let secondRow = typeof align === 'string' ? getAlignString(align) : align.map((s) => getAlignString(s)).join('|');
    return (0, prettier_1.formatCode)(_data.shift() + '\n' + secondRow + '\n' + _data.join('\n'), 'markdown');
}
function getAlignString(option) {
    const _ = '--';
    return option === 'l' ? ':' + _ : option === 'c' ? ':' + _ + ':' : option === 'r' ? _ + ':' : _;
}
function extractTableRow(step, reportCategories) {
    const nameAndMode = [step.name, step.gatherMode];
    let results;
    if (step.gatherMode === 'navigation') {
        results = Object.values(step.results).map((v) => {
            return v ? (v * 100).toFixed(0) + '' : '-';
        });
    }
    else {
        const existingCats = Object.keys(step.results);
        results = reportCategories.map(category => {
            if (!existingCats.includes(category)) {
                return '-';
            }
            const { totalWeight, numPassed, numPassableAudits } = step.results[category];
            const res = numPassed + '/' + numPassableAudits;
            return totalWeight === 0 ? 'Ø ' + res : res;
        });
    }
    return nameAndMode.concat(results);
}
//# sourceMappingURL=md-table.js.map